/*
 * This file was generated by qdbusxml2cpp version 0.7
 * Command line was: qdbusxml2cpp -a qibusfactoryadaptor -c IBusFactoryAdaptor -v org.freedesktop.IBus.EngineFactory.xml org.freedesktop.IBus.EngineFactory
 *
 * qdbusxml2cpp is Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef QIBUSFACTORYADAPTOR_H_1251169083
#define QIBUSFACTORYADAPTOR_H_1251169083

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
class QByteArray;
template<class T> class QList;
template<class Key, class Value> class QMap;
class QString;
class QStringList;
class QVariant;

/*
 * Adaptor class for interface org.freedesktop.IBus.EngineFactory
 */
class IBusFactoryAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.freedesktop.IBus.EngineFactory")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.freedesktop.IBus.EngineFactory\" >\n"
"    <method name=\"Destroy\" />\n"
"    <method name=\"CreateEngine\" >\n"
"      <arg direction=\"in\" type=\"s\" name=\"engine_name\" />\n"
"      <arg direction=\"out\" type=\"o\" />\n"
"    </method>\n"
"  </interface>\n"
        "")
public:
    IBusFactoryAdaptor(QObject *parent);
    virtual ~IBusFactoryAdaptor();

public: // PROPERTIES
public Q_SLOTS: // METHODS
    QDBusObjectPath CreateEngine(const QString &engine_name);
    void Destroy();
Q_SIGNALS: // SIGNALS
};

#endif
